==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AssigningPolarStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningPolarStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningPolarStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningPolarStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningPolarStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningPolarStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningPolarStyleEventArgsBaseDescriptionMetadata.c(AssigningPolarStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.j(AssigningPolarStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningPolarStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningPolarStyleEventArgsBaseDescriptionMetadata.b(a);
        a.z("AssigningPolarStyleEventArgsBase", AssigningPolarStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningPolarStyleEventArgsBaseDescriptionMetadata, 'AssigningPolarStyleEventArgsBaseDescriptionMetadata');
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningPolarStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningPolarStyleEventArgsBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningPolarStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningPolarStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningPolarStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningPolarStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningPolarStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningPolarStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningPolarStyleEventArgsBaseDescriptionMetadata.c(AssigningPolarStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.k(AssigningPolarStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningPolarStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningPolarStyleEventArgsBaseDescriptionMetadata.b(a);
        a.ab("AssigningPolarStyleEventArgsBase", AssigningPolarStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningPolarStyleEventArgsBaseDescriptionMetadata, 'AssigningPolarStyleEventArgsBaseDescriptionMetadata');
    AssigningPolarStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningPolarStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningPolarStyleEventArgsBaseDescriptionMetadata };
